'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactLibObjectAssign = require('react/lib/Object.assign');

var _reactLibObjectAssign2 = _interopRequireDefault(_reactLibObjectAssign);

function capitalize(string) {
  return string.charAt(0).toUpperCase() + string.slice(1);
}

function camelize(string) {
  return string.replace(/[\-_/\.\s]+(.)?/g, function (match, chr) {
    return chr.toUpperCase();
  }).replace(/^(.)/, function (match, chr) {
    return chr.toLowerCase();
  });
}

function getBaseClassName() {
  var options = arguments[0] === undefined ? {} : arguments[0];

  var baseClassName = undefined;
  var componentName = capitalize(camelize(options.componentName));

  baseClassName = options.namespace ? '' + options.namespace + '-' + componentName : componentName;
  baseClassName = options.descendantName ? '' + baseClassName + '-' + camelize(options.descendantName) : baseClassName;

  return baseClassName;
}

function getModifierClassNames() {
  var options = arguments[0] === undefined ? {} : arguments[0];

  var modifierClassNames = undefined;
  if (options.modifiers) {
    modifierClassNames = options.modifiers.split(' ').map(function (modifier) {
      return '' + getBaseClassName(options) + '--' + camelize(modifier);
    }).join(' ');
  }
  return modifierClassNames;
}

function getStateClassNames() {
  var options = arguments[0] === undefined ? {} : arguments[0];

  var stateClassNames = undefined;
  if (options.states) {
    stateClassNames = options.states.split(' ').map(function (state) {
      return 'is-' + camelize(state);
    }).join(' ');
  }
  return stateClassNames;
}

function getUtilityClassNames() {
  var options = arguments[0] === undefined ? {} : arguments[0];

  var utilityClassNames = undefined;
  if (options.utilities) {
    utilityClassNames = options.utilities.split(' ').map(function (utility) {
      return 'u-' + camelize(utility);
    }).join(' ');
  }
  return utilityClassNames;
}

var SuitCss = {
  propTypes: {
    utilities: _react2['default'].PropTypes.string
  },

  getClassName: function getClassName() {
    var config = arguments[0] === undefined ? {} : arguments[0];

    var defaults = {
      namespace: this.namespace || null,
      componentName: this.constructor.displayName,
      descendantName: null,
      modifiers: null,
      states: null,
      utilities: config.descendantName ? null : this.props.utilities || null
    };

    var options = (0, _reactLibObjectAssign2['default'])({}, defaults, config);

    var classNames = [getBaseClassName(options)].concat(getModifierClassNames(options), getStateClassNames(options), getUtilityClassNames(options), this.props.className).filter(function (e) {
      return e;
    }).join(' ');

    return classNames;
  }
};

exports['default'] = SuitCss;
module.exports = exports['default'];